@@ -10,7 +10,7 @@
 # Modules and declarations
 ##############################################################################
 
-package App::DocKnot 1.05;
+package App::DocKnot 1.06;
 
 use 5.024;
 use autodie;
@@ -173,22 +173,27 @@ sub _code_for_to_text {
             "\n\n" . $text;
         }xmsge;
 
-        # Remove URLs from all links, replacing them with numeric references,
-        # and accumulate the mapping of numbers to URLs in %urls.
-        my %urls;
+        # For each paragraph, remove URLs from all links, replacing them with
+        # numeric references, and accumulate the mapping of numbers to URLs in
+        # %urls.  Then, add to the end of the paragraph the references and
+        # URLs.
+        my @paragraphs = split(m{ \n\n }xms, $text);
         my $ref = 1;
-        while ($text =~ s{ \[ ([^\]]+) \] [(] (\S+) [)] }{$1 [$ref]}xms) {
-            $urls{$ref} = $2;
-            $ref++;
+        for my $para (@paragraphs) {
+            my %urls;
+            while ($para =~ s{ \[ ([^\]]+) \] [(] (\S+) [)] }{$1 [$ref]}xms) {
+                $urls{$ref} = $2;
+                $ref++;
+            }
+            if (%urls) {
+                my @refs = map { "[$_] $urls{$_}" } sort { $a <=> $b }
+                  keys(%urls);
+                $para .= "\n\n" . join("\n", q{}, @refs, q{});
+            }
         }
 
-        # If there are any URLs, add an additional paragraph with all the
-        # references and URLs.
-        if (%urls) {
-            my @refs = map { "[$_] $urls{$_}" } sort { $a <=> $b } keys(%urls);
-            $text .= join("\n", q{}, @refs, q{});
-        }
-        return $text;
+        # Rejoin the paragraphs and return the result.
+        return join("\n\n", @paragraphs);
     };
     return $to_text;
 }
@@ -423,6 +428,11 @@ sub _wrap_paragraph {
         return $paragraph;
     }
 
+    # If this looks like a bunch of short lines, leave it alone.
+    if ($paragraph =~ m{ \A [^\n]{1,40} \n [^\n]{1,40} \n }xms) {
+        return $paragraph;
+    }
+
     # If this paragraph is not consistently indented, leave it alone.
     if ($paragraph !~ m{ \A (?: \Q$indent\E \S[^\n]+ \n )+ \z }xms) {
         return $paragraph;
